@@ -1,4 +1,3 @@
-#!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
 #    Copyright (C) 2010  Carlos Perez
@@ -20,13 +19,9 @@
 from lxml import etree
 from lib.msf_print import *
 
-try:
-    from urllib import urlencode
-    from urllib2 import urlopen, Request, URLError, HTTPError
-except ImportError:
-    from urllib.request import urlopen, Request
-    from urllib.error import URLError, HTTPError
-    from urllib.parse import urlencode
+
+from urllib.request import urlopen, Request
+from urllib.error import URLError, HTTPError
 
 
 def scrape_crtsh(dom):
@@ -35,17 +30,17 @@ def scrape_crtsh(dom):
     """
     results = []
     headers = {'User-Agent': 'Mozilla/5.0 (X11; Linux x86_64; rv:31.0) Gecko/20100101 Firefox/31.0'}
-    url = 'https://crt.sh/?q=%25.{}'.format(dom)
+    url = f'https://crt.sh/?q=%25.{dom}'
 
     req = Request(url=url, headers=headers)
     try:
         resp = urlopen(req)
         data = resp.read()
-    except URLError as e:
-        print_error('Connection with crt.sh failed. Reason: "{}"'.format(e.reason))
-        return results
     except HTTPError as e:
-        print_error('Bad http status from crt.sh: "{}"'.format(e.code))
+        print_error(f'Bad http status from crt.sh: "{e.code}"')
+        return results
+    except URLError as e:
+        print_error(f'Connection with crt.sh failed. Reason: "{e.reason}"')
         return results
 
     root = etree.HTML(data)
@@ -59,7 +54,7 @@ def scrape_crtsh(dom):
         if not sub_dom.endswith('.' + dom):
             continue
         if sub_dom.startswith('*.'):
-            print_status("\t {} wildcard".format(sub_dom))
+            print_status(f"\t {sub_dom} wildcard")
             continue
         if sub_dom not in results:
             results.append(sub_dom)
